import { BaseLayer, SourceType, UserOptions } from 'wind-gl-core';
export { DecodeType, ImageSource, LayerSourceType, MaskType, RenderFrom, RenderType, TileID, TileSource, TimelineSource, configDeps } from 'wind-gl-core';
import * as maptalks from 'maptalks';
import { CanvasLayer } from 'maptalks';
import { Field, IField, IOptions } from 'wind-core';
export { Field, WindCore, formatData } from 'wind-core';
import { PerspectiveCamera, OrthographicCamera, Scene } from '@sakitam-gis/vis-engine';

declare class MaptalksWind extends CanvasLayer {
    private field;
    private _map;
    private options;
    constructor(id: string | number, data: any, options?: any);
    private pickWindOptions;
    /**
     * get wind layer data
     */
    getData(): Field | undefined;
    /**
     * set layer data
     * @param data
     * @param options
     * @returns {WindLayer}
     */
    setData(data: any, options?: Partial<IField>): this;
    setWindOptions(options: Partial<IOptions>): void;
    getWindOptions(): Partial<IOptions>;
    draw(): this;
    prepareToDraw(): never[];
    drawOnInteracting(): void;
    private _getRenderer;
}

interface BaseLayerOptionType extends UserOptions {
    renderer?: string;
    doubleBuffer?: boolean;
    glOptions?: {
        preserveDrawingBuffer: boolean;
    };
    forceRenderOnMoving?: boolean;
    forceRenderOnRotating?: boolean;
    forceRenderOnZooming?: boolean;
    requestWebGl2?: boolean;
}
declare class Layer extends maptalks.TileLayer {
    type: string;
    _needsUpdate: boolean;
    _coordCache: {};
    layer: WithNull<BaseLayer>;
    private source;
    private projWorldWidth;
    constructor(id: string, source: SourceType, opts: BaseLayerOptionType);
    onMoveStart(): void;
    onMoving(): void;
    onMoveEnd(): void;
    onDragRotateStart(): void;
    onDragRotateEnd(): void;
    onResize(): void;
    onZoomStart(): void;
    onZooming(): void;
    onZoomEnd(): void;
    update(): void;
    getWorlds(): {
        world: number;
        offset: number;
        xmin: number;
        xmax: number;
    }[];
    calcWitchWorld(center: number[], worlds: {
        world: number;
        offset: number;
        xmin: number;
        xmax: number;
    }[]): number | undefined;
    getClipMask(): any;
    private processMask;
    setClipMask(mask: any): void;
    prepareToDraw(gl: any, scene: any): false | undefined;
    isRendering(): boolean;
    draw(gl: any, view: any, scene: any, camera: any, timeStamp: any, context: any): void;
    drawOnInteracting(gl: any, view: any, scene: any, camera: any, event: any, timeStamp: any, context: any): void;
    getObjects(): any[];
    clear(): this;
    clearObject(): this;
    getCamera(): WithNull<PerspectiveCamera | OrthographicCamera>;
    getScene(): WithNull<Scene>;
    renderScene(context?: any, layer?: any): this;
    onAdd(): this;
    onRemove(): this;
    getEvents(): {
        _zoomstart: () => void;
        _zooming: () => void;
        _zoomend: () => void;
        _resize: () => void;
        _movestart: () => void;
        _moving: () => void;
        _moveend: () => void;
        _dragrotatestart: () => void;
        _dragrotateend: () => void;
    };
}

export { Layer, MaptalksWind as WindLayer };
